@@ -101,7 +101,7 @@ class Install(InstallPlugin):
         packages=set()
         ## system role
         if 'Backend' not in self.type:
-            packages.add('libnet-upnp-perl') #causes mythtv-backend to be removed
+            packages.add('mythtv-backend')
             packages.add('php5-common')      #causes mythweb to be removed
             packages.add('libaprutil1')      #causes apache2 to be removed
         if 'Slave' in self.type or self.type == 'Frontend':
@@ -122,7 +122,9 @@ class Install(InstallPlugin):
     def setup_common(self):
         #Always generate a new password
         #If the user has a security key, that trumps anyway (via config.xml)
-        new_pass_caller = subprocess.Popen(['pwgen','-s','8'],stdout=subprocess.PIPE)
+        new_pass_caller = subprocess.Popen(
+            ['pwgen', '-s', '8'], stdout=subprocess.PIPE,
+            universal_newlines=True)
         answer = new_pass_caller.communicate()[0].split()[0]
         install_misc.set_debconf(self.target, 'mythtv/mysql_mythtv_password', answer)
 
